==> syotools-1.1.1.tar.gz: syotools-1.1.1/setup.py <==
from setuptools import setup

setup(name="syotools",
      version="1.1.1",
      description="Science Yield Optimization Tools (SYOTools)", 
      author="Jason Tumlinson, STScI", 
      author_email="tumlinson@stsci.edu",
      license="BSD",
      keywords=["simulation", "astronomy", "astrophysics"],
      url="https://github.com/spacetelescope/hwo-tools",
      packages=["syotools", "syotools/coronagraph", "syotools/data", 
                "syotools/pysynphot_data","syotools/defaults",  
                "syotools/interface", "syotools/models", "syotools/persistence",  
                "syotools/spectra", "syotools/utils", "syotools/wrappers", "syotools/sci_eng_interface"],
      package_data={'':['*.yaml', '*.fits', 'fesc/*txt', '*.txt', '*.dat', 
                    'pysynphot_data/calspec/*','pysynphot_data/comp/*', 
                    'pysynphot_data/grid/*','pysynphot_data/mtab/*', 
                    'pysynphot_data/comp/nonhst/*', 'pysynphot_data/grid/agn/*',
                    'pysynphot_data/grid/galactic/*', 'pysynphot_data/grid/kc96/*',
                    'pysynsphot_data/grid/pickles/*', 'pysynphot_data/grid/pickles/dat_uvk/*', 
                    'sci_eng_interface/*json']}, 
      include_package_data=True,
      classifiers=[
          "Programming Language :: Python :: 3.6",
      ],
      install_requires=[
            "setuptools>=61.0", 
            "astropy>6", 
            "pysynphot==2.0.0", 
            "numpy", 
            "scipy", 
            "specutils", 
      ],
)

==> syotools-1.1.2.tar.gz: syotools-1.1.2/setup.py <==
from setuptools import setup

setup(name="syotools",
      version="1.1.2",
      description="Science Yield Optimization Tools (SYOTools)", 
      author="Jason Tumlinson, STScI", 
      author_email="tumlinson@stsci.edu",
      license="BSD",
      keywords=["simulation", "astronomy", "astrophysics"],
      url="https://github.com/spacetelescope/hwo-tools",
      packages=["syotools", "syotools/coronagraph", "syotools/data", 
                "syotools/pysynphot_data","syotools/defaults",  
                "syotools/interface", "syotools/models", "syotools/persistence",  
                "syotools/spectra", "syotools/utils", "syotools/wrappers", "syotools/sci_eng_interface"],
      package_data={'':['*.yaml', '*.fits', 'fesc/*txt', '*.txt', '*.dat', 
                    'pysynphot_data/calspec/*','pysynphot_data/comp/*', 
                    'pysynphot_data/grid/*','pysynphot_data/mtab/*', 
                    'pysynphot_data/comp/nonhst/*', 'pysynphot_data/grid/agn/*',
                    'pysynphot_data/grid/galactic/*', 'pysynphot_data/grid/kc96/*', 'pysynphot_data/grid/etc_models/*', 
                    'pysynsphot_data/grid/pickles/*', 'pysynphot_data/grid/pickles/dat_uvk/*', 
                    'sci_eng_interface/*json']}, 
      include_package_data=True,
      classifiers=[
          "Programming Language :: Python :: 3.6",
      ],
      install_requires=[
            "setuptools>=61.0", 
            "astropy>6", 
            "pysynphot==2.0.0", 
            "numpy", 
            "scipy", 
            "specutils", 
      ],
)
